<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Http\Exception\NotFoundException;
use Cake\Mailer\Email;
use Cake\ORM\TableRegistry;
use Cake\Form\Form;
use Cake\Auth\DefaultPasswordHasher;
use Cake\Utility\Security;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\Event\Event;

/**
 * Myaccounts Controller
 *
 * @property \App\Model\Table\MyaccountsTable $Myaccounts
 * @method \App\Model\Entity\ProfileAccount[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class MyaccountsController extends AppController
{
    /**
     * Initialization hook method.
     *
     * Use this method to add common initialization code like loading components.
     *
     * e.g. `$this->loadComponent('Security');`
     *
     * @return void
     */
    public function initialize()
    {
        parent::initialize();
        $this->loadModel('Myaccounts');
        $this->loadModel('GhisepMemebers');

        $this->loadModel('Contacts');

        $this->Auth->allow(['forgotPassword']);
    }



    public function signup()
    {
        $myAccountUsers = $this->Myaccounts->newEntity();

        if ($this->request->is('post')) {
            $token = Security::hash(Time::now(), 'sha1', true); //for hashing token 
            $this->request->data['token'] = $token;
            $verification_code = substr((number_format(time() * rand(), 0, '', '')), 0, 6);
            $this->request->data['verification_code'] = $verification_code;
            $userEmail = $this->request->data['email'];

            $myAccountUsers = $this->Myaccounts->patchEntity($myAccountUsers, $this->request->getData());
            $contact = TableRegistry::get('Contacts')->find('All')->first();

            $image = $this->request->getUploadedFile('image_file'); // get image name from the forms
            $name = $image->getClientFilename();
            $targetPath = WWW_ROOT . 'img' . DS . $name; // this saves images to  the web root image folder

            if ($name)
                $image->moveTo($targetPath);
            $myAccountUsers->image_path = $name;

            if ($this->Myaccounts->save($myAccountUsers)) {
                session_start();

                $_SESSION["useremail"] = $userEmail;

                $verificationMsg = "<p>Your verification code is: <b style='font-size: 30px;'>  <br/> $verification_code </p>";
                echo $verificationMsg;
                // $email = new Email('default');
                // $email->from([$contact->form_email1 => 'Seed Ghana'])
                //     ->to($userEmail)
                //     ->emailFormat('html')
                //     ->subject('Email Verification')
                //     ->send($verificationMsg);

                //  echo "<script>alert('The user has been saved.');</script>";

                return $this->redirect(['action' => 'activateAccount']);
            }
            $this->set('myAccountUsers', $myAccountUsers);
        }
    }

    public function activateAccount()
    {
        session_start();
        $profileEmail = $_SESSION["useremail"];

        $userProfiles = TableRegistry::get('Myaccounts')->find('All')->first();

        if ($this->request->is(['post'])) {

            $email = $this->request->data['email'];
            $verification_code = $this->request->data['verification_code'];

            if ($userProfiles->email == $email && $userProfiles->verification_code == $verification_code) {
                $id = $userProfiles->id;
                $MyaccountsTable = TableRegistry::getTableLocator()->get('Myaccounts');
                $userProfile = $MyaccountsTable->get($id);
                $userProfile->status = 1;

                if ($MyaccountsTable->save($userProfile)) {
                    return $this->redirect(['action' => 'login']);
                }

            } else {
                $this->Flash->error(__('Incorrect code, please try agian'));
            }

        }
        $this->set(compact('profileEmail'));
    }

    public function confirmationCode()
    {
        $userProfiles = TableRegistry::get('Myaccounts')->find('All')->first();

        if ($this->request->is(['post'])) {

            $email = $this->request->data['email'];
            $verification_code = $this->request->data['verification_code'];

            if ($userProfiles->email == $email && $userProfiles->verification_code == $verification_code) {
                $id = $userProfiles->id;
                $MyaccountsTable = TableRegistry::getTableLocator()->get('Myaccounts');
                $userProfile = $MyaccountsTable->get($id);
                $userProfile->status = 1;
                $MyaccountsTable->save($userProfile);

                return $this->redirect(['action' => 'login']);
            } else {
                $this->Flash->error(__('Incorrect code, please try agian'));
            }

        }
    }


    public function resendVerificationCode()
    {
        session_start();
        $profileEmail = $_SESSION["useremail"];

        $userProfiles = TableRegistry::get('Myaccounts')->find('All')->first();

        $contact = TableRegistry::get('Contacts')->find('All')->first();


        $verification_code = substr((number_format(time() * rand(), 0, '', '')), 0, 6);

        if ($userProfiles->email == $profileEmail) {

            $id = $userProfiles->id;
            $MyaccountsTable = TableRegistry::getTableLocator()->get('Myaccounts');
            $userProfile = $MyaccountsTable->get($id);
            $userProfile->verification_code = $verification_code;

            if ($MyaccountsTable->save($userProfile)) {
                $verificationMsg = "<p>Your verification code is: <b style='font-size: 30px;'>  <br/> $verification_code </p>";

                $email = new Email('default');
                $email->from([$contact->form_email1 => 'Seed Ghana'])
                    ->to($profileEmail)
                    ->emailFormat('html')
                    ->subject('Email Verification')
                    ->send($verificationMsg);
            }

        }
        return $this->redirect($this->referer());
    }

    public function login()
    {
        if ($this->request->is('post')) {
            $ProfileAccount = $this->Auth->identify();
            if ($ProfileAccount) {
                if ($ProfileAccount['status'] == 1) {
                    $this->Auth->setUser($ProfileAccount);
                    return $this->redirect(['action' => 'dashboard']);
                } else {
                    $this->Flash->error(__('Account is not activated, Please activate your account'));
                }
            } else {
                $this->Flash->error('Your username or password is incorrect.');
            }
        }
    }

    public function dashboard()
    {
        $userId = $this->Auth->user('id');
        $title = $this->Auth->user('title');
        $firstName = $this->Auth->user('first_name');
        $lastName = $this->Auth->user('last_name');
        $image = $this->Auth->user('image_path');
        $gender = $this->Auth->user('gender');
        $dateOfBirth = $this->Auth->user('date_of_birth');
        $email = $this->Auth->user('email');
        $phone = $this->Auth->user('phone_1');

        $this->set(compact('title', 'firstName', 'lastName', 'image', 'gender', 'dateOfBirth', 'email', 'phone','userId'));
    }

    public function logout()
    {
        $this->Flash->success('You are now logged out.');
        return $this->redirect($this->Auth->logout());

    }

    public function forgotPassword()
    {

        $userProfiles = TableRegistry::get('Myaccounts')->find('All')->first();

        $contact = TableRegistry::get('Contacts')->find('All')->first();

        if ($this->request->is(['post'])) {
            $userEmail = $this->request->data['email'];

            if ($userProfiles->email == $userEmail) {
                $passwordReset = substr((number_format(time() * rand(), 0, '', '')), 0, 6);

                ///replace old password with new password  
                $id = $userProfiles->id;
                $MyaccountsTable = TableRegistry::getTableLocator()->get('Myaccounts');
                $userProfile = $MyaccountsTable->get($id);
                $userProfile->password = $passwordReset;

                if ($MyaccountsTable->save($userProfile)) {
                    $verificationMsg = "<p>Enter the code below as your password on the login Page to gain access to your portal.
                       <b style='font-size: 30px;'>  <br/> $passwordReset </p>";

                    $email = new Email('default');
                    $email->from([$contact->form_email1 => 'Seed Ghana'])
                        ->to($userEmail)
                        ->emailFormat('html')
                        ->subject('Temporal Portal Login Password')
                        ->send($verificationMsg);
                }

            } else {
                $this->Flash->error('Sorry,your email does not exist');
            }
        }

    }

    function changepassword()
    {
        $myAccountUsers = $this->Myaccounts->newEntity();
        if ($this->request->is('post')) {
            $hasher = new DefaultPasswordHasher();

            $oldPasswd = $this->request->getdata('passwd');

            $newPassword = $this->request->getdata('password');

            $passWordConfirm = $this->request->getdata('passWordConfirm');

            $id = $this->Auth->user('id');

            $userProfiles = TableRegistry::get('Myaccounts')->find('All')->first();
            $hashedPasswordDb = $userProfiles->password;

            if ($userProfiles->id = $id) {

                if ($hasher->check($oldPasswd, $hashedPasswordDb)) {
                    if ($newPassword == $passWordConfirm) {
                        $MyaccountsTable = TableRegistry::getTableLocator()->get('Myaccounts');

                        ///replace old password with new password 
                        $userProfiles->password = $newPassword;
                        $MyaccountsTable->save($userProfiles);


                    } else {
                        $this->Flash->error(__('Passwords mismatch'));
                    }
                    $this->Flash->success('Password changed successfully.');

                } else {
                    $this->Flash->error(__('Old Password is incorrect'));
                }

                // echo $hashedPasswordDb;
            }

        }
        // return $this->redirect(['action' => 'dashboard']);
        $this->set('myAccountUsers', $myAccountUsers);
    }
}