<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Http\Exception\NotFoundException;

/**
 * Static services controller
 *
 * This controller will render views from Template/AboutUs/
 *
 */
class ProductsController extends AppController
{
    public function initialize()
    {
        parent::initialize();
        $this->loadModel('PageProducts');
        $this->loadModel('PageContents');
        $this->loadModel('Products');
        $this->loadModel('Banners');
        $this->loadModel('Files');
        $this->loadModel('Galleries');
    }

    public function index()
    {
        $this->request->params['section'] = 'products';
        $menuDetails = $this->PageContents->Menus->find('all', [
			'conditions' => [
				'slug' => $this->request->getParam('section')
			]
		])->first();


    // Load the banners. Banners are normally loaded at the top of the page.
		// So lets add it to the sections.
		// Append to any section if you want to show as well, could be carousel, etc....
		$banners = $this->Banners->find('all', [
			'conditions' => [
				'status' => 5
			]
		])
		->order(['rand()'])
		->limit(1)
		->toArray();

  $condition = ['PageProducts.menu_id' => $menuDetails->id];

  $viewContent = $this->PageProducts->Products->find('all', [
    'contain' => [
      'ProductImages', 'PageProducts'
      
    ],
    'conditions' => [
      'status' => 1
    ]
  
  ])->matching('PageProducts', function ($q) use($condition) {
    return $q->where($condition);
  })->toArray();

        $this->set(compact('viewContent', 'menuDetails', 'banners', 'files','otherDownloads'));

        
    }

    public function subMenu()
    {
		// Loading content and basic processes to load the content has been implemented in the content
		// The section for this method is already set in the params of the request object
		// So lets just call the parent method
//dd($this->request->getAttribute('params'));

    $menuDetails = $this->PageProducts->Menus->find('all', [
			'conditions' => [
				'slug' => $this->request->getParam('subsection')
			]
		])->first();

  
$condition = ['PageProducts.menu_id' => $menuDetails->id];

  $viewContent = $this->PageProducts->Products->find('all', [
    'contain' => [
      'ProductImages', 'PageProducts'
      
    ],
    'conditions' => [
      'status' => 1
    ]
  
  ])->matching('PageProducts', function ($q) use($condition) {
    return $q->where($condition);
  });
 
      
  // /**
  //  * Perform additional task here before sending the values
  //  * to be rendered on the view
  //  */
  //  // Retrieve the submenus of this menu
  //  // We will use this to display sub menus in the form of category page / view
   $categoryContents = $this->PageContents->Menus->find('all', [
       'contain' => [
           'ParentMenus'    
       ],
       'conditions' => [
           'Menus.parent_menu_id' => $menuDetails->id,
           'Menus.status' => 1
         ]
     ]);
  
  // // Initialize the content array and populate the contents of each section
  $homeAlbums = $this->Galleries->Albums->find('all', [
    'contain' => [
      'Galleries'
    ],
    'conditions' => [
      'Albums.status' => 1,
      'Albums.show_on_home' => 1
    ]
  ])->toArray();
  
  // // Load the banners. Banners are normally loaded at the top of the page.
  // // So lets add it to the sub sections.
  // // Append to any section if you want to show as well, could be carousel, etc....
  $banners = $this->Banners->find('all', [
    'conditions' => [
      'status' => 5
    ]
  ])
  ->order(['rand()'])
  ->limit(1)
  ->toArray();
  
  
  // // Load details on sub menus list
  $subMenuLists = $this->PageContents->Menus->find('all', [
    'conditions' => [
      'status' => '1',
      'parent_menu_id' => $menuDetails->id
    ]
  ]);
  
  // // Load the files for the page.
  // // For now lets load all the files, 
  // // we will show it on the relevant pages.
  // // TODO: Fix the file associations for the menus
  $files = $this->Files->find('all', [
    'conditions' => [
      'status' => 1
    ]
  ])
  ->toArray();
   $this->set(compact('menuDetails','viewContent','submenus', 'categoryContents', 'banners', 'subMenuLists', 'files', 'homeAlbums'));
  $this->render('sub_menu');
    }


    public function details($id = null)
    {
      // $this->loadModel('Carts'); 
      // $count=$this->Carts->getCount();
     
		/** 
		 * The selected menu is in the section param of the request
		 * 
		 * Lets retreive the data and load the content for that sub section
		 * 
		 */
    //dd($this->request->getAttribute('params'));
		
		
		// Get the full details of the content with the id
		$viewDetails = $this->PageProducts->Products->find('all', [
			'contain' => [
				'ProductImages', 'PageProducts'
			],
			'conditions' => [
				'Products.status' => 1,
				'Products.id' => $id
			]
		])->first();

		if($viewDetails == null) {
			$this->log('No details found for content with ID: ' . $id, 'debug');
			throw new NotFoundException();
		}
		
		/**
		 * Perform additional task here before sending the values
		 * to be rendered on the view
		 */
  
    
		$banners = $this->Banners->find('all', [
			'conditions' => [
				'status' => 5
			]
		])
		->order(['rand()'])
		->limit(1)
		->toArray();

    $this->request->params['section'] = 'products';
    $menuDetails = $this->PageContents->Menus->find('all', [
      'conditions' => [
         'slug' => $this->request->getParam('section')
  ]])->first();
		
		 /**
		  * Set the final values to the view
		  */
     // $this->set('count',$this->Cart->getCount());
   
		$this->set(compact('viewDetails','banners','count','menuDetails'));
    }
}

?>