<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Http\Exception\NotFoundException;
use Cake\Mailer\Email;
use Cake\ORM\TableRegistry;
use Cake\Form\Form;
use Cake\Auth\DefaultPasswordHasher;
use Cake\Utility\Security;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\Event\Event;

/**
 * ProfileAccounts Controller
 *
 * @property \App\Model\Table\ProfileAccountsTable $ProfileAccounts
 * @method \App\Model\Entity\ProfileAccount[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class ProfileAccountsController extends AppController
{
     /**
     * Initialization hook method.
     *
     * Use this method to add common initialization code like loading components.
     *
     * e.g. `$this->loadComponent('Security');`
     *
     * @return void
     */
    public function initialize()
    {
        parent::initialize();
        $this->loadModel('ProfileAccounts');
        $this->loadModel('Contacts');
    }

    public function home()
    {
        echo 'welcome';
    }
    
     public function signup()
    {
        $userProfile = $this->ProfileAccounts->newEntity();

        if ($this->request->is('post')) {
            $token = Security::hash(Time::now(), 'sha1', true); //for hashing token 
            $this->request->data['token'] = $token;
            $verification_code = substr((number_format(time() * rand(), 0, '', '')), 0, 6);
            $this->request->data['verification_code'] = $verification_code;
            $userEmail = $this->request->data['email'];
            
            $userProfile = $this->ProfileAccounts->patchEntity($userProfile, $this->request->getData());
            $contact = TableRegistry::get('Contacts')->find('All')->first();
            
            $image = $this->request->getUploadedFile('image_file'); // get image name from the forms
            $name = $image->getClientFilename();
            $targetPath = WWW_ROOT . 'img' . DS . $name; // this saves images to  the web root image folder
            
            if ($name)
             $image->moveTo($targetPath);
             $userProfile->image_path = $name;
             
             if ($this->ProfileAccounts->save($userProfile)) {
                session_start();
                 
                 $_SESSION["useremail"] = $userEmail;
                 
                 $verificationMsg = "<p>Your verification code is: <b style='font-size: 30px;'>  <br/> $verification_code </p>";
                 
                //  $email = new Email('default');
                //  $email->from([$contact->form_email1 => 'Seed Ghana'])
                //  ->to($userEmail)
                //  ->emailFormat('html')
                //  ->subject('Email Verification')
                //  ->send($verificationMsg);
                 
                //  echo "<script>alert('The user has been saved.');</script>";
                 
                 return $this->redirect(['action' => 'activateAccount']);
             }
             else{
                // echo "<script>alert('The user could not be saved. Please, try again.');</script>";
                           $this->Flash->error(__('The user could not be saved. Please, try again.'));
             }
        }
    }
    
   public function activateAccount()
    {
        session_start();
        $profileEmail = $_SESSION["useremail"];

        $userProfiles = TableRegistry::get('ProfileAccounts')->find('All')->first();

        if ($this->request->is(['post'])) {

            $email = $this->request->data['email'];
            $verification_code = $this->request->data['verification_code'];

            if ($userProfiles->email == $email && $userProfiles->verification_code == $verification_code) {
                $id = $userProfiles->id;
                $profileAccountsTable = TableRegistry::getTableLocator()->get('ProfileAccounts');
                $userProfile = $profileAccountsTable->get($id);
                $userProfile->status_id = 1;
                $profileAccountsTable->save($userProfile);

                return $this->redirect(['action' => 'login']);
            } else {
                $this->Flash->error(__('Incorrect code, please try agian'));
            }

        }
        $this->set(compact('profileEmail'));
    }
    
     public function confirmationCode()
     {
         $userProfiles = TableRegistry::get('ProfileAccounts')->find('All')->first();
         
            if ($this->request->is(['post'])) {
                 
             $email = $this->request->data['email'];
             $verification_code = $this->request->data['verification_code'];
             
            if($userProfiles->email == $email && $userProfiles->verification_code == $verification_code ){
                $id = $userProfiles->id;
                $profileAccountsTable = TableRegistry::getTableLocator()->get('ProfileAccounts');
                $userProfile = $profileAccountsTable->get($id);
                $userProfile->status_id = 1;
                $profileAccountsTable->save($userProfile);

                return $this->redirect(['action' => 'login']);
            }
            else{
                $this->Flash->error(__('Incorrect code, please try agian'));
            }

         }
    }
    

    public function resendVerificationCode(){

    }

    public function login()
    {
        if ($this->request->is('post')) {
            $ProfileAccount = $this->Auth->identify();
            if ($ProfileAccount) {
                if($ProfileAccount['status_id'] == 1){
                    $this->Auth->setUser($ProfileAccount);
                    return $this->redirect(['action' => 'home']);
                }else{
                $this->Flash->error(__('Account is not activated, Please activate your account'));
                    }
            }else{
                $this->Flash->error('Your username or password is incorrect.');
            }
        }
    }

    public function logout()
    {
        $this->Flash->success('You are now logged out.');
        return $this->redirect($this->Auth->logout());
        
    }

    function forgotPassword(){ 


    }
    
    
    
    
}