<?php
declare(strict_types=1);

namespace App\Controller;

use App\Controller\AppController;
use cake\ORM\TableRegistry;
use Cake\Mailer\Email;
use Cake\Auth\DefaultPasswordHasher;
use Cake\Utility\Security;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\Event\Event;

/**
 * Users Controller
 *
 * @property \App\Model\Table\UsersTable $Users
 * @method \App\Model\Entity\User[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class UsersController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $users = $this->paginate($this->Users);

        $this->set(compact('users'));
    }

    /**
     * View method
     *
     * @param string|null $id User id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $user = $this->Users->get($id, [
            'contain' => ['UserContacts', 'UserEducations', 'UserEmploymentExpertises', 'UserPaymentDetails'],
        ]);

        $this->set(compact('user'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $user = $this->Users->newEmptyEntity();
        if ($this->request->is('post')) {
            $user = $this->Users->patchEntity($user, $this->request->getData());
            if ($this->Users->save($user)) {
                $this->Flash->success(__('The user has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The user could not be saved. Please, try again.'));
        }
        $this->set(compact('user'));
    }

    /**
     * Edit method
     *
     * @param string|null $id User id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $user = $this->Users->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $user = $this->Users->patchEntity($user, $this->request->getData());
            if ($this->Users->save($user)) {
                $this->Flash->success(__('The user has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The user could not be saved. Please, try again.'));
        }
        $this->set(compact('user'));
    }

    /**
     * Delete method
     *
     * @param string|null $id User id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $user = $this->Users->get($id);
        if ($this->Users->delete($user)) {
            $this->Flash->success(__('The user has been deleted.'));
        } else {
            $this->Flash->error(__('The user could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }

    public function login(){
        if ($this->request->is('post')) {
            $user = $this->Auth->identify();
            // debug($user);
            // exit;
            if ($user) {
                if($user['status_id'] == 1){
            $this->Auth->setUser($user);
            // return $this->redirect(['controller'=>'Users','action'=>'add']);
            return $this->redirect($this->Auth->redirectUrl());
            }  else{
                $this->Flash->error(__('Account is not activated, Please activate your account'));
                    }
            }else{
                $this->Flash->error('Your username or password is incorrect.');
            }
        }
    }

    public function logout(){
        $this->Flash->success('You are now logged out.');
        return $this->redirect($this->Auth->logout());
    }

    function forgotPassword(){ 

        if($this->request->is('post')){
            // email from the form and retrieve user details
            $user = $this->Users->find('all')->where(['email'=>strtolower($this->request->data['email'])])->first();

            if(!empty($user)){
                // Update account and send email to user
                $token=Security::hash( Time::now(),'sha1', true);
                // $user->token_pw = $token;
                // echo $token;

                $UserTable = TableRegistry::get('Users');
                $user = $UserTable->find('all')->where(['email'=>$user->email])->first();
                $user->password = '';
                $user->token_pw = $token;

                if($UserTable->save($user)){
                    $this->Flash->success('Reset password link has been sent to your email ('.$user->email.')');

                    $email = new Email();
                    $email->transport('default');
                    $email->from('admin@gyeak.com')
                    ->to($user->email)
                    ->subject('Please confirm to reset password')
                    ->send('hello'.$user->first_name.'please click the link below to reset password<br/><br/>
                    <a href="https://gyeak.com/qa1/site/users/forgot-password/'.$user->token_pw.'"></a>');

                }
            }
            else{
                $this->Flash->error('The email address you provided is not registered with our system. Thank you');
            } 
        }
    }

    function restPassword($token){
        if($this->request->is('post')){
            $hasher = new DefaultPasswordHasher();
            $newPassword = $hasher->hash($this->request->getdata('new_password'));

            $UserTable = TableRegistry::get('Users');
            $user = $UserTable->find('all')->where(['token_pw'=>$token])->first();
            $user->password = $newPassword;

            if($UserTable->save($user)){
                return $this->redirect(['controller' => 'Users', 'action' => 'login']);
            }
    }


}

}