<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * GhisepMemebers Model
 *
 * @property \App\Model\Table\MyaccountsTable&\Cake\ORM\Association\BelongsTo $Myaccounts
 *
 * @method \App\Model\Entity\GhisepMemeber newEmptyEntity()
 * @method \App\Model\Entity\GhisepMemeber newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\GhisepMemeber[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\GhisepMemeber get($primaryKey, $options = [])
 * @method \App\Model\Entity\GhisepMemeber findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\GhisepMemeber patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\GhisepMemeber[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\GhisepMemeber|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\GhisepMemeber saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\GhisepMemeber[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\GhisepMemeber[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\GhisepMemeber[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\GhisepMemeber[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class GhisepMemebersTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('ghisep_memebers');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Myaccounts', [
            'foreignKey' => 'myaccounts_id',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('myaccounts_id')
            ->allowEmptyString('myaccounts_id');

        $validator
            ->scalar('office_phone')
            ->maxLength('office_phone', 50)
            ->allowEmptyString('office_phone');

        $validator
            ->scalar('business_address')
            ->maxLength('business_address', 255)
            ->notEmptyString('business_address');

        $validator
            ->scalar('mobile_phone')
            ->maxLength('mobile_phone', 50)
            ->allowEmptyString('mobile_phone');

        $validator
            ->scalar('home_address')
            ->maxLength('home_address', 255)
            ->notEmptyString('home_address');

        $validator
            ->scalar('preferred_mailing_address')
            ->maxLength('preferred_mailing_address', 50)
            ->requirePresence('preferred_mailing_address', 'create')
            ->notEmptyString('preferred_mailing_address');

        $validator
            ->scalar('level')
            ->maxLength('level', 255)
            ->allowEmptyString('level');

        $validator
            ->scalar('institution')
            ->maxLength('institution', 255)
            ->allowEmptyString('institution');

        $validator
            ->scalar('institution_address')
            ->maxLength('institution_address', 255)
            ->allowEmptyString('institution_address');

        $validator
            ->integer('country_id')
            ->allowEmptyString('country_id');

        $validator
            ->scalar('qualification')
            ->maxLength('qualification', 50)
            ->allowEmptyString('qualification'); 

       $validator
            ->scalar('certificate')
            ->maxLength('certificate', 50)
            ->notEmptyString('certificate');

        $validator
            ->scalar('continue_edu_course')
            ->maxLength('continue_edu_course', 255)
            ->allowEmptyString('continue_edu_course');

        $validator
            ->scalar('current_place_of_employment')
            ->maxLength('current_place_of_employment', 100)
            ->allowEmptyString('current_place_of_employment');

        $validator
            ->scalar('current_position_title')
            ->maxLength('current_position_title', 100)
            ->allowEmptyString('current_position_title');

        $validator
            ->scalar('current_position_duration')
            ->maxLength('current_position_duration', 50)
            ->allowEmptyString('current_position_duration');

        $validator
            ->scalar('first_previous_place_of_employment')
            ->maxLength('first_previous_place_of_employment', 100)
            ->allowEmptyString('first_previous_place_of_employment');

        $validator
            ->scalar('first_previous_position_title')
            ->maxLength('first_previous_position_title', 100)
            ->allowEmptyString('first_previous_position_title');

        $validator
            ->scalar('first_previous_position_duration')
            ->maxLength('first_previous_position_duration', 50)
            ->allowEmptyString('first_previous_position_duration');

        $validator
            ->scalar('second_previous_place_of_employment')
            ->maxLength('second_previous_place_of_employment', 100)
            ->allowEmptyString('second_previous_place_of_employment');

        $validator
            ->scalar('second_previous_position_title')
            ->maxLength('second_previous_position_title', 100)
            ->allowEmptyString('second_previous_position_title');

        $validator
            ->scalar('second_previous_position_duration')
            ->maxLength('second_previous_position_duration', 50)
            ->allowEmptyString('second_previous_position_duration');

        $validator
            ->scalar('total_years_in_related_work')
            ->maxLength('total_years_in_related_work', 50)
            ->allowEmptyString('total_years_in_related_work');

        $validator
            ->boolean('mining_safety')
            ->allowEmptyString('mining_safety');

        $validator
            ->boolean('forestry')
            ->allowEmptyString('forestry');

        $validator
            ->boolean('transportation')
            ->allowEmptyString('transportation');

        $validator
            ->boolean('emergency_services')
            ->allowEmptyString('emergency_services');

        $validator
            ->boolean('fire_prevention')
            ->allowEmptyString('fire_prevention');

        $validator
            ->boolean('community')
            ->allowEmptyString('community');

        $validator
            ->boolean('manufacturing')
            ->allowEmptyString('manufacturing');

        $validator
            ->boolean('industrial_hygiene')
            ->allowEmptyString('industrial_hygiene');

        $validator
            ->boolean('training_education')
            ->allowEmptyString('training_education');

        $validator
            ->boolean('consulting')
            ->allowEmptyString('consulting');

        $validator
            ->boolean('oil_energy')
            ->allowEmptyString('oil_energy');

        $validator
            ->boolean('food_processing')
            ->allowEmptyString('food_processing');

        $validator
            ->boolean('environmental')
            ->allowEmptyString('environmental');

        $validator
            ->boolean('ergonomics')
            ->allowEmptyString('ergonomics');

        $validator
            ->boolean('construction')
            ->allowEmptyString('construction');

        $validator
            ->boolean('public_services')
            ->allowEmptyString('public_services');

        $validator
            ->boolean('engineering')
            ->allowEmptyString('engineering');

        $validator
            ->boolean('healthcare')
            ->allowEmptyString('healthcare');

        $validator
            ->boolean('insurance')
            ->allowEmptyString('insurance');

        $validator
            ->boolean('telecommunication')
            ->allowEmptyString('telecommunication');

        $validator
            ->boolean('other')
            ->allowEmptyString('other');

        $validator
            ->scalar('other_expertise')
            ->maxLength('other_expertise', 100)
            ->allowEmptyString('other_expertise');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('myaccounts_id', 'Myaccounts'), ['errorField' => 'myaccounts_id']);

        return $rules;
    }
}
