<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Myaccounts Model
 *
 * @method \App\Model\Entity\Myaccount newEmptyEntity()
 * @method \App\Model\Entity\Myaccount newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\Myaccount[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Myaccount get($primaryKey, $options = [])
 * @method \App\Model\Entity\Myaccount findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\Myaccount patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Myaccount[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\Myaccount|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Myaccount saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Myaccount[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Myaccount[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\Myaccount[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Myaccount[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class MyaccountsTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('myaccounts');
        $this->setDisplayField('title');
        $this->setPrimaryKey('id');

        $this->hasMany('GhisepMemebers', [
            'foreignKey' => 'myaccounts_id'
        ]);

        // $this->hasMany('PageContents', [
        //     'foreignKey' => 'content_id'
        // ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->scalar('image_path')
            ->maxLength('image_path', 255)
            ->allowEmptyFile('image_path');

        $validator
            ->scalar('title')
            ->maxLength('title', 255)
            ->allowEmptyString('title');

        $validator
            ->scalar('first_name')
            ->maxLength('first_name', 255)
            ->requirePresence('first_name', 'create')
            ->notEmptyString('first_name');

        $validator
            ->scalar('last_name')
            ->maxLength('last_name', 255)
            ->requirePresence('last_name', 'create')
            ->notEmptyString('last_name');

        $validator
            ->scalar('gender')
            ->maxLength('gender', 255)
            ->allowEmptyString('gender');

        $validator
            ->scalar('date_of_birth')
            ->maxLength('date_of_birth', 255)
            ->allowEmptyString('date_of_birth');

        $validator
            ->scalar('phone_1')
            ->maxLength('phone_1', 255)
            ->requirePresence('phone_1', 'create')
            ->notEmptyString('phone_1');

        $validator
            ->scalar('phone_2')
            ->maxLength('phone_2', 20)
            ->allowEmptyString('phone_2');

        $validator
            ->email('email')
            ->notEmptyString('email');

        $validator
            ->scalar('alternative_email')
            ->maxLength('alternative_email', 255)
            ->allowEmptyString('alternative_email');

        $validator
            ->scalar('password')
            ->maxLength('password', 255)
            ->notEmptyString('password');

        $validator
            ->sameAs('passwordConfirm','password','Confirm password does not match password');

        $validator
            ->integer('status')
            ->allowEmptyString('status');

        $validator
            ->scalar('token')
            ->maxLength('token', 255)
            ->allowEmptyString('token');

        $validator
            ->dateTime('token_created_at')
            ->allowEmptyDateTime('token_created_at');

        $validator
            ->scalar('verification_code')
            ->allowEmptyString('verification_code');

        $validator
            ->dateTime('last_accessed')
            ->allowEmptyDateTime('last_accessed');

        $validator
            ->integer('registration_stage_id')
            ->allowEmptyString('registration_stage_id');

        $validator
            ->scalar('token_pw')
            ->maxLength('token_pw', 50)
            ->allowEmptyString('token_pw');

        return $validator;
    }

        /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->isUnique(['email']));

       
        return $rules;
    }
}
